@@ -71,6 +71,8 @@ struct _PulseaudioNotify
 
   gboolean              gauge_notifications;
   NotifyNotification   *notification;
+
+  gulong                volume_changed_id;
 };
 
 struct _PulseaudioNotifyClass
@@ -102,6 +104,7 @@ pulseaudio_notify_init (PulseaudioNotify *notify)
 
   notify->gauge_notifications = TRUE;
   notify->notification = NULL;
+  notify->volume_changed_id = 0;
 
   //g_set_application_name ("Xfce volume control");
   notify_init ("Xfce volume control");
@@ -119,7 +122,7 @@ pulseaudio_notify_init (PulseaudioNotify *notify)
       g_list_free (caps_list);
     }
   notify->notification = notify_notification_new ("xfce4-pulseaudio-plugin", NULL, NULL);
-  notify_notification_set_timeout (notify->notification, 1500);
+  notify_notification_set_timeout (notify->notification, 2000);
 }
 
 
@@ -140,29 +143,41 @@ pulseaudio_notify_finalize (GObject *object)
 
 
 
-void
+static void
 pulseaudio_notify_notify (PulseaudioNotify *notify)
 {
   GError      *error = NULL;
   gdouble      volume;
   gint         volume_i;
   gboolean     muted;
+  gboolean     connected;
   gchar       *title = NULL;
   const gchar *icon = NULL;
 
   g_return_if_fail (IS_PULSEAUDIO_NOTIFY (notify));
   g_return_if_fail (IS_PULSEAUDIO_VOLUME (notify->volume));
 
+  if (!pulseaudio_config_get_show_notifications (notify->config))
+    return;
+
   volume = pulseaudio_volume_get_volume (notify->volume);
   muted = pulseaudio_volume_get_muted (notify->volume);
+  connected = pulseaudio_volume_get_connected (notify->volume);
   volume_i = (gint) round (volume * 100);
 
-  if (muted)
+  if (!connected)
+    volume_i = 0;
+
+  if (!connected)
+    title = g_strdup_printf ( _("Not connected to the PulseAudio server"));
+  else if (muted)
     title = g_strdup_printf ( _("Volume %d%c (muted)"), volume_i, '%');
   else
     title = g_strdup_printf ( _("Volume %d%c"), volume_i, '%');
 
-  if (muted)
+  if (!connected)
+    icon = icons[V_MUTED];
+  else if (muted)
     icon = icons[V_MUTED];
   else if (volume <= 0.0)
     icon = icons[V_MUTED];
@@ -198,6 +213,17 @@ pulseaudio_notify_notify (PulseaudioNotify *notify)
 
 
 
+static void
+pulseaudio_notify_volume_changed (PulseaudioNotify  *notify,
+                                  PulseaudioVolume  *volume)
+{
+  g_return_if_fail (IS_PULSEAUDIO_NOTIFY (notify));
+
+  pulseaudio_notify_notify (notify);
+}
+
+
+
 PulseaudioNotify *
 pulseaudio_notify_new (PulseaudioConfig *config,
                        PulseaudioVolume *volume)
@@ -211,6 +237,9 @@ pulseaudio_notify_new (PulseaudioConfig *config,
 
   notify->config = config;
   notify->volume = volume;
+  notify->volume_changed_id =
+    g_signal_connect_swapped (G_OBJECT (notify->volume), "volume-changed",
+                              G_CALLBACK (pulseaudio_notify_volume_changed), notify);
 
   return notify;
 }
